package controller

import (
	"bigdata_archives/app/e"
	"bigdata_archives/app/model"
	"bigdata_archives/app/service"
	"github.com/gin-gonic/gin"
	"github.com/go-playground/validator/v10"
	"strconv"
)

var SystemSetting service.SystemSettings = &model.SystemSettings{}

// GetSystemSetting 获取系统设置
func GetSystemSetting(c *gin.Context) {
	settings, rescode := SystemSetting.GetSystemSettings()
	if rescode != e.SUCCESS {
		e.ResponseWithMsg(c, rescode, "获取系统设置失败")
		return
	}
	e.ResponseSuccess(c, settings)
}

// CreateSystem 创建系统设置
func CreateSystem(c *gin.Context) {
	var system model.SystemSettings
	if err := c.ShouldBindJSON(&system); err != nil {
		e.ResponseWithMsg(c, e.JSONParsingFailed, e.JSONParsingFailed.GetMsg())
		return
	}
	settings, rescode := SystemSetting.CreateSystemSettings(system)
	if rescode != e.SUCCESS {
		e.ResponseWithMsg(c, rescode, "创建系统设置失败")
		return
	}
	e.ResponseSuccess(c, settings)
}

// UpdateSystem 更新系统设置
func UpdateSystem(c *gin.Context) {
	var system model.SystemSettings
	if err := c.ShouldBindJSON(&system); err != nil {
		e.ResponseWithMsg(c, e.JSONParsingFailed, e.JSONParsingFailed.GetMsg())
		return
	}
	settings, rescode := SystemSetting.UpdateSystemSettings(system)
	if rescode != e.SUCCESS {
		e.ResponseWithMsg(c, rescode, "更新系统设置失败")
		return
	}
	e.ResponseSuccess(c, settings)
}

// DeleteSystem 删除系统设置
func DeleteSystem(c *gin.Context) {
	value := c.Query("id")
	id, _ := strconv.Atoi(value)
	err := validator.New().Var(id, "required")
	if err != nil {
		e.ResponseWithMsg(c, e.CheckRequired, e.CheckRequired.GetMsg())
		return
	}
	settings, rescode := SystemSetting.DeleteSystemSettings(id)
	if rescode != e.SUCCESS {
		e.ResponseWithMsg(c, rescode, "删除系统设置失败")
		return
	}
	e.ResponseSuccess(c, settings)
}
